/*
 * utime.h
 */


#ifndef utime_h
#define utime_h


#include <sys/utime.h>


extern int utime(const char *, struct utimbuf *);


#endif
